<?xml version="1.0"?>
<!-- purpletoxhtml.xsl ===============================================
     Author: Eugene Eric Kim <eekim@eekim.com>
     URL: http://www.eekim.com/software/purple/

     Version: 0.3
     $Id: purpletoxhtml.xsl,v 1.2 2001/05/01 06:16:57 eekim Exp $

     Copyright (c) Eugene Eric Kim 2000-2001.  All rights reserved.
     See COPYING for licensing terms.
================================================================== -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    version="1.0">

<!-- =================================================================
     This XSLT script corresponds almost exactly to purpletohtml.xsl.
     The only differences are that this script generates XML, not
     HTML, and I removed the constructs for generating hacked HTML.  I
     also removed the comment tags surrounding the CSS stylesheet -
     they're only necessary for non-HTML compliant browsers.  These
     are not left out of "clean" mode for purpletohtml, because the
     required conditional would look too ugly.  (You would need a
     conditional block surrounding the entire xsl:comment block,
     rather than around the start and end xsl:comment tags, because
     XSLT scripts must be well-formed XML.)
================================================================== -->

<xsl:output method="xml" indent="yes"/>

<!-- ===== global variables ===== -->
<xsl:param name="css"/> <!-- use this file for styles instead of style tag -->
<xsl:variable name="version" select="0.3"/>

<!-- ===== construct result set ===== -->
<xsl:template match="/">
  <html>
    <head>
      <title><xsl:value-of select="purple/docinfo/title"/></title>
      <meta name="generator" content="Purple v{$version}"/>
      <xsl:if test="$css">
      <link href="{$css}" rel="stylesheet" type="text/css"/>
      </xsl:if>
      <style type="text/css">
           body {
             background-color:#FFFFFF; padding-bottom: 50em;}
           h1.title {text-align: center;}
           p.docinfo {text-align: center;}
           p.footer {text-align: right;}
           div.indented {margin-left: 3em;}
           div.example {
             display:block; background-color:#C0FFFF;
             margin-left:10%; margin-right:10%;
             border-width:1pt;}
           div.image {display:block; margin-left:10%; margin-right:10%;}
           p.caption {margin-left:10%; margin-right:10%;}
           <!-- purple numbers -->
           <xsl:if test="$css = false()">
           a.hid {
             font-family: "Helvetica", "Arial", sans-serif;
             font-size: x-small;
             font-style: italic;
             font-weight: bold;
             text-decoration: none;
             color: #C8A8FF;}
           a.sid {
             font-family: "Helvetica", "Arial", sans-serif;
             font-style: normal;
             font-weight: bold;
             font-size: x-small;
             text-decoration: none;
             color: #C8A8FF;}
           </xsl:if>
      </style>
    </head>
    <body>
      <h1 class="title"><xsl:value-of select="purple/docinfo/title"/></h1>

      <p class="docinfo">
      <!-- check for multiple authors.  If there are more than one,
           output each of them separated by line breaks.  The count() is
           probably unnecessary; I'm trying to avoid the extraneous break
           element at the end of the paragraph, but if there are multiple
           authors, you get the extraneous break anyway. -->
      <xsl:choose>
        <xsl:when test="count(purple/docinfo/author) = 1">
          <xsl:value-of select="purple/docinfo/author/name"/>
          <xsl:text> </xsl:text>
          <a href="mailto:{purple/docinfo/author/email}">&lt;<xsl:value-of select="purple/docinfo/author/email"/>&gt;</a>
        </xsl:when>
        <xsl:otherwise>
          <xsl:for-each select="purple/docinfo/author">
            <xsl:value-of select="name"/>
            <xsl:text> </xsl:text>
            <a href="mailto:{email}">&lt;<xsl:value-of select="email"/>&gt;</a>
            <br/>
          </xsl:for-each>
        </xsl:otherwise>
      </xsl:choose>
      </p>

      <p class="docinfo">Version
      <xsl:value-of select="purple/docinfo/version"/><br/>
      <xsl:value-of select="purple/docinfo/datepublished"/>
      </p>

      <hr />

      <xsl:apply-templates select="purple/section"/>

      <hr />

      <p class="footer"><i>Document developed using
      <a href="http://www.eekim.com/software/purple/">Purple</a></i></p>
    </body>
  </html>
</xsl:template>

<xsl:template match="section">
  <h3><a name="{h/@sid}" /><a name="{h/@hid}" /><xsl:value-of select="h"/>
  &#xA0;&#xA0;<a class="hid" href="#{h/@hid}"><xsl:value-of select="h/@hid"/></a>&#xA0;
  <a class="sid" href="#{h/@sid}">(<xsl:value-of select="h/@sid"/>)</a>
  </h3>
  <div class="indented">
  <xsl:apply-templates select="p | list | example | figure | section"/>
  </div>
</xsl:template>

<xsl:template match="p">
  <p><a name="{@sid}" /><a name="{@hid}" /><xsl:apply-templates select="text() | link | i | b"/>
  &#xA0;&#xA0;
  <a class="hid" href="#{@hid}"><xsl:value-of select="@hid"/></a>&#xA0;
  <a class="sid" href="#{@sid}">(<xsl:value-of select="@sid"/>)</a>
  </p>
</xsl:template>

<xsl:template match="list">
  <ul>
    <xsl:apply-templates/>
  </ul>
</xsl:template>

<xsl:template match="item">
  <li><a name="{@sid}" /><a name="{@hid}" /><xsl:apply-templates select="text() | link | i | b"/>
  &#xA0;&#xA0;
  <a class="hid" href="#{@hid}"><xsl:value-of select="@hid"/></a>&#xA0;
  <a class="sid" href="#{@sid}">(<xsl:value-of select="@sid"/>)</a>
  </li>
</xsl:template>

<xsl:template match="example">
  <div class="example"><pre><a name="{@sid}" /><a name="{@hid}" /><a name="ex-{@num}"/><xsl:value-of select="listing"/></pre></div>
  <p class="caption"><b>Example <xsl:value-of select="@num"/>.</b><xsl:text> </xsl:text>
  <xsl:value-of select="caption"/>
  &#xA0;&#xA0;
  <a class="hid" href="#{@hid}"><xsl:value-of select="@hid"/></a>&#xA0;
  <a class="sid" href="#{@sid}">(<xsl:value-of select="@sid"/>)</a>
  </p>
</xsl:template>

<xsl:template match="figure">
  <div class="image"><a name="{@sid}" /><a name="{@hid}" /><a name="fig-{@num}"/><img src="{image/@src}" alt="[Figure {@num}]"/></div>
  <p class="caption"><b>Figure <xsl:value-of select="@num"/>.</b><xsl:text> </xsl:text>
  <xsl:value-of select="caption"/>
  &#xA0;&#xA0;
  <a class="hid" href="#{@hid}"><xsl:value-of select="@hid"/></a>&#xA0;
  <a class="sid" href="#{@sid}">(<xsl:value-of select="@sid"/>)</a>
  </p>
</xsl:template>

<!-- formatting elements -->

<xsl:template match="text()">
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template match="link">
  <a href="{@href}"><xsl:value-of select="."/></a>
</xsl:template>

<xsl:template match="i">
  <i><xsl:value-of select="."/></i>
</xsl:template>

<xsl:template match="b">
  <b><xsl:value-of select="."/></b>
</xsl:template>

</xsl:stylesheet>
