#!/usr/bin/perl
#
# rm_ids.pl
#
# Eugene Eric Kim <eekim@eekim.com>
# http://www.eekim.com/software/purple/
#
# $Id: rm_ids.pl,v 1.3 2001/05/01 06:57:09 eekim Exp $
#
# Copyright (c) Eugene Eric Kim 2000-2001.  All rights reserved.
# See COPYING for licensing terms.

=head1 NAME

rm_ids.pl - Remove statement IDs and hierarchical addresses from a
purple.dtd XML file.

=head1 SYNOPSIS

Usage:
  rm_ids.pl file.xml

=head1 DESCRIPTION

Parses the XML file conforming to purple.dtd, and removes all SIDs and
hierarchical addresses.  Saves the original XML file to file.xml~.

This script is not very robust.  It doesn't validate the XML file, and
it doesn't handle errors well.  So be careful.

There also seems to be a bug with XML::DOM.  When you call
$doc->printToFile, it does not encode the greater than entity (&gt;).

=cut

use strict;
use File::Copy;
use XML::DOM;

my $file = $ARGV[0];
if (!$file) {
  print <<EOM;
Usage:
  $0 file.xml

where file.xml is an XML file conforming to purple.dtd.
EOM
  exit;
}
File::Copy::move($file, "$file~");
&XML::DOM::setTagCompression(\&my_tag_compression);
my $parser = new XML::DOM::Parser;
my $doc = $parser->parsefile("$file~");

### remove SIDs and HIDs

&remove_ids('h');
&remove_ids('p');
&remove_ids('item');
&remove_ids('example');
&remove_ids('figure');
&remove_lastsid;

### print to file

$doc->printToFile("$file");

# fini

### subroutines

sub remove_ids {
  my $element_name = shift;
  my @nodes = $doc->getElementsByTagName($element_name);

  foreach my $node (@nodes) {
	$node->removeAttribute('sid');
	$node->removeAttribute('hid');
  }
}

sub remove_lastsid {
  my @nodes = $doc->getElementsByTagName('lastsid');
  my $node = ($nodes[0]->getChildNodes)[0];

  $nodes[0]->removeChild($node);
}


sub my_tag_compression {
  my ($tag, $elem) = @_;

  return 1 if ($tag =~ /^(lastsid|p)$/);
  return 0;
}

=head1 AUTHOR

Eugene Eric Kim <eekim@eekim.com>

=cut
